aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--oni-core.el5
1 files changed, 3 insertions, 2 deletions
diff --git a/oni-core.el b/oni-core.el
index 156900f..0c2aebc 100644
--- a/oni-core.el
+++ b/oni-core.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.0227.150537
;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -166,6 +166,7 @@ _s_: String list"
(global-set-key (kbd "C-x C-b") 'ibuffer-jump)
(global-set-key (kbd "C-x M-f") 'ffap)
(global-set-key (kbd "M-+") 'mc/mark-next-like-this)
+(global-set-key [remap insert-char] 'insert-char-preview)
(global-set-key [remap move-beginning-of-line] #'oni-core-move-beginning-of-dwim)
(global-set-key [remap move-end-of-line] #'oni-core-move-end-of-dwim)
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2021.0227.150537
-;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key)
+;; Version: 2021.0227.153915
+;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by